==> haskell-pretty-show-1.6.16-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pretty-show.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pretty-show
version: 1.6.16
id: pretty-show-1.6.16-4yL3QMm4omX5sydQq6eqFv
key: pretty-show-1.6.16-4yL3QMm4omX5sydQq6eqFv
license: MIT
maintainer: iavor.diatchki@gmail.com
homepage: http://wiki.github.com/yav/pretty-show
synopsis: Tools for working with derived `Show` instances and generic
          inspection of values.
description:
    We provide a library and an executable for working with derived '\''Show'\''
    instances. By using the library, we can parse derived '\''Show'\'' instances into a
    generic data structure. The @ppsh@ tool uses the library to produce
    human-readable versions of '\''Show'\'' instances, which can be quite handy for
    debugging Haskell programs.  We can also render complex generic values into
    an interactive Html page, for easier examination.
category: Text
author: Iavor S. Diatchki
exposed: True
indefinite: False
exposed-modules:
    Text.Show.Pretty
hidden-modules: Text.Show.Html Text.Show.Parser Text.Show.Value
                Text.Show.PrettyVal Paths_pretty_show
abi: a68af35cb8ebe4069d7cae43e78dc845
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/pretty-show-1.6.16
library-dirs: /usr/lib/ghc-8.2.2/site-local/pretty-show-1.6.16
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-pretty-show
hs-libraries: HSpretty-show-1.6.16-4yL3QMm4omX5sydQq6eqFv
depends:
    array-0.5.2.0 base-4.10.1.0
    haskell-lexer-1.0.1-1drChWRMvNxE3y4irvVxwM pretty-1.1.3.3
    filepath-1.4.1.2 ghc-prim-0.5.1.1
abi-depends: array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             haskell-lexer-1.0.1-1drChWRMvNxE3y4irvVxwM=fcd6528587829290fe2050cfcd7f0f48
             pretty-1.1.3.3=229bcf5342145ac1755207fe83d29780
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
haddock-interfaces: /usr/share/doc/haskell-pretty-show/html/pretty-show.haddock
haddock-html: /usr/share/doc/haskell-pretty-show/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pretty-show-1.7-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pretty-show.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pretty-show
version: 1.7
id: pretty-show-1.7-I6moT2kFY2TJ3qMVHEcAXl
key: pretty-show-1.7-I6moT2kFY2TJ3qMVHEcAXl
license: MIT
maintainer: iavor.diatchki@gmail.com
homepage: http://wiki.github.com/yav/pretty-show
synopsis: Tools for working with derived `Show` instances and generic
          inspection of values.
description:
    We provide a library and an executable for working with derived '\''Show'\''
    instances. By using the library, we can parse derived '\''Show'\'' instances into a
    generic data structure. The @ppsh@ tool uses the library to produce
    human-readable versions of '\''Show'\'' instances, which can be quite handy for
    debugging Haskell programs.  We can also render complex generic values into
    an interactive Html page, for easier examination.
category: Text
author: Iavor S. Diatchki
exposed: True
indefinite: False
exposed-modules:
    Text.Show.Pretty
hidden-modules: Text.Show.Html Text.Show.Parser Text.Show.Value
                Text.Show.PrettyVal Paths_pretty_show
abi: e75ab5e88c2cabf7b42da611951c78c3
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/pretty-show-1.7
library-dirs: /usr/lib/ghc-8.2.2/site-local/pretty-show-1.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-pretty-show
hs-libraries: HSpretty-show-1.7-I6moT2kFY2TJ3qMVHEcAXl
depends:
    array-0.5.2.0 base-4.10.1.0
    haskell-lexer-1.0.1-1drChWRMvNxE3y4irvVxwM pretty-1.1.3.3
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz filepath-1.4.1.2
    ghc-prim-0.5.1.1
abi-depends: array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             haskell-lexer-1.0.1-1drChWRMvNxE3y4irvVxwM=fcd6528587829290fe2050cfcd7f0f48
             pretty-1.1.3.3=229bcf5342145ac1755207fe83d29780
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
haddock-interfaces: /usr/share/doc/haskell-pretty-show/html/pretty-show.haddock
haddock-html: /usr/share/doc/haskell-pretty-show/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
